InsertAffiliateFlutterSDK class
Methods
-
addListener(VoidCallback listener)
→ void
-
Register a closure to be called when the object changes.
inherited
-
captureInstallReferrer({int retryCount = 0})
→ Future<bool>
-
-
dispose()
→ void
-
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
errorLog(String message, [String type = "log"])
→ void
-
-
fetchOfferCode(String affiliateLink)
→ Future<String?>
-
-
getActiveCompanyCode()
→ Future<String?>
-
-
getAffiliateAttributionTimeout()
→ Future<int>
-
Gets the current timeout period in seconds for affiliate attribution.
Returns the default of 0 (disabled) if not explicitly set.
-
getAffiliateDetails(String affiliateCode)
→ Future<AffiliateDetails?>
-
Retrieves detailed information about an affiliate by their short code or deep link
This method queries the API and does not store or set the affiliate identifier
Returns AffiliateDetails if found, null otherwise
-
getAffiliateStoredDate()
→ Future<DateTime?>
-
Returns the date when the affiliate attribution was stored.
Returns null if no attribution date is found.
-
getClipboardUUID()
→ Future<String?>
-
-
getCompanyCode()
→ String
-
-
getEnhancedSystemInfo()
→ Future<Map<String, dynamic>>
-
-
getNetworkInfo()
→ Future<Map<String, dynamic>>
-
-
getNetworkPathInfo()
→ Future<Map<String, dynamic>>
-
-
getStoredOfferCode()
→ Future<String?>
-
-
getSystemInfo()
→ Future<Map<String, dynamic>>
-
-
handleCustomURLScheme(String url, String protocol)
→ Future<bool>
-
-
handleDeepLink(String url)
→ Future<bool>
-
-
handleInsertLinkAndroid(String url)
→ Future<bool>
-
-
handleInsertLinks(String url)
→ Future<bool>
-
-
isAffiliateAttributionValid()
→ Future<bool>
-
Checks if the affiliate attribution is still valid based on the timeout period.
Returns true if attribution is valid or no timeout is set, false if expired.
-
isShortCode(String link)
→ bool
-
-
isValidUUID(String string)
→ bool
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners()
→ void
-
Call all the registered listeners.
inherited
-
parseShortCodeFromURLString(String url)
→ String?
-
-
parseURL(String url)
→ Map<String, String>
-
-
processInstallReferrerData(String rawReferrer)
→ Future<bool>
-
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
retrieveAndStoreOfferCode(String affiliateLink)
→ Future<void>
-
-
returnInsertAffiliateIdentifier({bool ignoreTimeout = false})
→ Future<String?>
-
-
returnUserAccountTokenAndStoreExpectedTransaction()
→ Future<String?>
-
-
sendSystemInfoToBackend(Map<String, dynamic> systemInfo)
→ Future<void>
-
-
setAffiliateAttributionTimeout(int timeoutSeconds)
→ Future<void>
-
Sets the timeout period in seconds for affiliate attribution.
Set to 0 or negative value to disable timeout (attribution never expires).
-
setInsertAffiliateIdentifier(String referringLink)
→ Future<void>
-
-
setInsertAffiliateIdentifierChangeCallback(InsertAffiliateIdentifierChangeCallback? callback)
→ void
-
-
setShortCode(String shortCode)
→ Future<bool>
-
Validates and sets a short code for affiliate tracking
Returns true if the short code exists and was successfully validated and stored, false otherwise
-
storeExpectedStoreTransaction(String purchaseToken)
→ Future<void>
-
-
storeInsertAffiliateIdentifier({required String link, required AffiliateAssociationSource source})
→ Future<void>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
trackEvent({required String eventName})
→ Future<void>
-
-
validatePurchaseWithIapticAPI(Map<String, dynamic> jsonIapPurchase, String iapticAppId, String iapticAppName, String iapticPublicKey)
→ Future<bool>
-
-
verboseLog(String message)
→ void
-